<?php

/*------------------------------------------*/
/* WPZOOM: Directory						*/
/*------------------------------------------*/

class wpzoom_widget_directory extends WP_Widget {

	/* Widget setup. */
	function __construct() {
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wpzoom', 'description' => __('Displays a specific number of sub-pages from a parent page.', 'wpzoom') );

		/* Widget control settings. */
		$control_ops = array( 'id_base' => 'wpzoom-widget-directory' );

		/* Create the widget. */
		parent::__construct( 'wpzoom-widget-directory', __('WPZOOM: Directory Pages', 'wpzoom'), $widget_ops, $control_ops );
	}

	/* How to display the widget on the screen. */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$page_id = $instance['page_id'];
		$page_order = $instance['page_order'] == 'date_new' || $instance['page_order'] == 'date_old' ? 'date' : $instance['page_order'];
		$page_order_dir = isset( $instance['page_order_dir'] ) && $instance['page_order_dir'] == 'asc' ? 'ASC' : 'DESC';
 		$page_number = $instance['page_number'];
 		$show_excerpt = $instance['page_excerpt'];
		$show_subtitle = $instance['page_subtitle'];


		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Title of widget (before and after defined by themes). */
		if ( $title )

			echo '<a class="dir_all" href="'. get_page_link($page_id). '">'.__('View All', 'wpzoom').'</a>';
			echo $before_title . $title . $after_title;

		?>
		<ul class="wpzoom-featured-pages wpzoom-dir-pages featured-pages-4">
		<?php
			$i = 0;

			if ($page_id > 0) {
				$loop = new WP_Query( array( 'posts_per_page' => $page_number, 'orderby' => $page_order, 'order' => $page_order_dir, 'post_parent' => $page_id, 'post_type' => 'page' ) );

				while ( $loop->have_posts() ) : $loop->the_post(); global $post; unset($page_subtitle); $i++;
				$page_subtitle = get_post_meta($post->ID, 'wpzoom_page_meta_title', true);
				?>

				<li class="wpzoom-featured-page wpzoom-dir-pages wpzoom-featured-page-<?php echo $i; ?>">

					<div class="post-cover">

						<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">

							<div class="post-content">

								<div class="post-content-wrapper">

									<?php if ($page_subtitle && $show_subtitle == 'on') { ?><span class="featured-page-meta"><?php echo $page_subtitle; ?></span><?php } ?>

				 					<h2 class="title title-post"><?php the_title(); ?></h2>

								</div><!-- .post-content-wrapper -->
							</div><!-- .post-content -->


							<?php
								get_the_image( array( 'size' => 'thumb-featured-page-4', 'width' => 280, 'height' => 180, 'before' => '', 'after' => '', 'link_to_post' => false ) );
							?>
						</a>

					</div><!-- .post-cover -->

					<?php if ($show_excerpt == 'on') { ?><p class="post-excerpt"><?php echo get_the_excerpt(); ?></p><?php } ?>

					<div class="cleaner">&nbsp;</div>

				</li><!-- .wpzoom-featured-page .wpzoom-featured-page -->

				<?php if ($i == 4) { $i = 0; } ?>

			<?php endwhile;

		} // while ?>



		</ul><!-- .wpzoom-featured-pages .featured-pages-3 -->

		<?php
		// echo $after_widget;
		wp_reset_query();

		/* After widget (defined by themes). */
		echo $after_widget;

		}

		/* Update the widget settings.*/
		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			/* Strip tags for title and name to remove HTML (important for text inputs). */
			$instance['title'] = $new_instance['title'];
			$instance['page_id'] = $new_instance['page_id'];
			$instance['page_order'] = $new_instance['page_order'];
			$instance['page_order_dir'] = $new_instance['page_order_dir'];
 			$instance['page_number'] = $new_instance['page_number'];
 			$instance['page_excerpt'] = $new_instance['page_excerpt'];
			$instance['page_subtitle'] = $new_instance['page_subtitle'];

			return $instance;
		}

		/** Displays the widget settings controls on the widget panel.
		 * Make use of the get_field_id() and get_field_name() function when creating your form elements. This handles the confusing stuff. */
		function form( $instance ) {

			/* Set up some default widget settings. */
			$defaults = array('title' => '', 'page_id' => '0', 'page_order' => 'none', 'page_order_dir' => 'desc', 'page_number' => 8, 'page_excerpt' => 'on', 'page_subtitle' => 'on');
			$instance = wp_parse_args( (array) $instance, $defaults );

			/* Support old widget options */
			if ( $instance['page_order'] == 'date_new' || $instance['page_order'] == 'date_old' ) {
				$instance['page_order'] = 'date';
			}
	    ?>

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Widget title', 'wpzoom'); ?>:</label><br />
				<input id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" type="text" class="widefat" />
			</p>

 			<p>
				<label for="<?php echo $this->get_field_id('page_id'); ?>"><?php _e('Select parent page:', 'wpzoom'); ?></label>
				<?php wp_dropdown_pages( array(  'show_option_none' => __( '— Select —', 'wpzoom' ),  'option_none_value' => '0', 'name' => $this->get_field_name('page_id'), 'id' => $this->get_field_id('page_id'), 'selected' => (int) $instance['page_id'] ) ); ?>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'page_order' ); ?>"><?php _e('Order', 'wpzoom'); ?>: </label>
				<select id="<?php echo $this->get_field_id( 'page_order' ); ?>" name="<?php echo $this->get_field_name( 'page_order' ); ?>">
					<option value="none" <?php if ( $instance['page_order'] == 'none' ) echo 'selected="selected"'; ?>><?php _e('Default', 'wpzoom'); ?></option>
					<option value="title" <?php if ( $instance['page_order'] == 'title' ) echo 'selected="selected"'; ?>><?php _e('By Title Alphabetically', 'wpzoom'); ?></option>
					<option value="date" <?php if ( $instance['page_order'] == 'date' ) echo 'selected="selected"'; ?>><?php _e('By Creation Date', 'wpzoom'); ?></option>
					<option value="menu_order" <?php if ( $instance['page_order'] == 'menu_order' ) echo 'selected="selected"'; ?>><?php _e('By Page Order', 'wpzoom'); ?></option>
				</select>
				<select id="<?php echo $this->get_field_id( 'page_order_dir' ); ?>" name="<?php echo $this->get_field_name( 'page_order_dir' ); ?>">
					<option value="asc" <?php if ( $instance['page_order_dir'] == 'asc' ) echo 'selected="selected"'; ?>><?php _e('Ascending', 'wpzoom'); ?></option>
					<option value="desc" <?php if ( $instance['page_order_dir'] == 'desc' ) echo 'selected="selected"'; ?>><?php _e('Descending', 'wpzoom'); ?></option>
				</select>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'page_number' ); ?>"><?php _e('Number of pages', 'wpzoom'); ?>: </label>
				<input id="<?php echo $this->get_field_id( 'page_number' ); ?>" name="<?php echo $this->get_field_name( 'page_number' ); ?>" value="<?php echo $instance['page_number']; ?>" type="text" size="2" />
			</p>


			<p>
				<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('page_excerpt'); ?>" name="<?php echo $this->get_field_name('page_excerpt'); ?>" <?php if ($instance['page_excerpt'] == 'on') { echo ' checked="checked"';  } ?> />
				<label for="<?php echo $this->get_field_id('page_excerpt'); ?>"><?php _e('Display page excerpt', 'wpzoom'); ?></label>
			</p>

			<p>
				<input class="checkbox" type="checkbox" id="<?php echo $this->get_field_id('page_subtitle'); ?>" name="<?php echo $this->get_field_name('page_subtitle'); ?>" <?php if ($instance['page_subtitle'] == 'on') { echo ' checked="checked"';  } ?> />
				<label for="<?php echo $this->get_field_id('page_subtitle'); ?>"><?php _e('Display page subtitle', 'wpzoom'); ?></label>
			</p>

		<?php
		}
}

function wpzoom_register_directory_widget() {
	register_widget('wpzoom_widget_directory');
}
add_action('widgets_init', 'wpzoom_register_directory_widget');
?>