/**
 * Theme functions file
 */

(function($) {
    var $document = $(document);
    var $window = $(window);

    $document.ready(function() {
        /**
         * Activate parallax effect on FlexSlider.
         */
        $('#slider').sllider();

        /**
         * Activate Headroom.
         */
        $('.header-inner-wrap').headroom({
            tolerance: {
                up: 75,
                down: 5
            },
            offset : 91
        });

        /**
         * Fix content position after Headeroom.
         */
        $('.headroom').next().css('padding-top', $('.headroom').outerHeight());

        /**
         * Clickable divs.
         */
        $(".clickable").on('click', function() {
            window.location.href = $(this).data("href");
        });

        /**
         * Don't duplicate placeholders.
         */
        var $fields = $('#respond input, #respond textarea');
        if ( $fields.length > 0 && 'placeholder' in $fields[0] ) {
            $('#respond').find('#commentform p label').hide();
        }

        mobileadjust();

        $window.on('resize', function() {
            mobileadjust();
        });
    });

    /**
     * Mobile menu support.
     */
    (function() {
        var pageOffsetY;
        var $toggleBtn = $('.navbar-toggle');
        var $menu = $($toggleBtn.data('target'));
        var $header = $('#header');

        $toggleBtn.on('click', function() {
            if ($toggleBtn.hasClass('active')) {
                disablePopover();
            } else {
                enablePopover();
            }

            return false;
        });

        $window.on('resize orientationchange', update);
        update();

        function update() {
            disablePopover();
            $menu.attr('style', '');

            if($window.width() <= 1200) {
                $('#menu ul.dropdown').superfish('destroy');
            } else {
                $('#menu ul.dropdown:not(.sf-js-enabled)').superfish({
                    delay: 0,
                    animation: { height: 'show', opacity: 'show' },
                    speed: 'fast'
                });
            }

            /**
             * Headroom compatibility.
             */
            $('.headroom').next().css('padding-top', $('.headroom').outerHeight());
        }

        function enablePopover() {
            $toggleBtn.addClass('active');
            pageOffsetY = window.pageYOffset;

            $menu.css('display', 'block');
            $header.addClass('has-menu-overlay');
            $menu.addClass('menu-overlay').css('top', $('.headroom').outerHeight());

            $('#header').height('50%');

            $('.site-container').css({
                height: '100%',
                overflow: 'hidden'
            });

            $('body')
                .addClass('noscroll')
                .css('top', -pageOffsetY + 'px');
        }

        function disablePopover() {
            $toggleBtn.removeClass('active');
            $menu
                .css('display', 'none')
                .removeClass('menu-overlay');
            $header.removeClass('has-menu-overlay');
            $('#header').height('auto');
            $('body').removeClass('noscroll');
            $(window).scrollTop(pageOffsetY);
        }
    })();

    /**
     * Parallax slider effects jQuery plugin.
     */
    $.fn.sllider = function() {
        var features = {
            bind : !!(function(){}.bind),
            rAF : !!(window.requestAnimationFrame || window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame)
        };

        if (typeof features === 'undefined' || !features.rAF || !features.bind) return;

        /**
         * Handles debouncing of events via requestAnimationFrame
         * @see http://www.html5rocks.com/en/tutorials/speed/animations/
         * @param {Function} callback The callback to handle whichever event
         */
        function Debouncer (callback) {
            this.callback = callback;
            this.ticking = false;
        }
        Debouncer.prototype = {
            constructor : Debouncer,

            /**
             * dispatches the event to the supplied callback
             * @private
             */
            update : function() {
                this.callback && this.callback();
                this.ticking = false;
            },

            /**
             * ensures events don't get stacked
             * @private
             */
            requestTick : function() {
                if(!this.ticking) {
                    requestAnimationFrame(this.rafCallback || (this.rafCallback = this.update.bind(this)));
                    this.ticking = true;
                }
            },

            /**
             * Attach this as the event listeners
             */
            handleEvent : function() {
                this.requestTick();
            }
        };

        return this.each(function () {
            var $this = $(this);
            var debouncer = new Debouncer(update.bind(this));

            $(window).on('scroll', debouncer.handleEvent.bind(debouncer));
            debouncer.handleEvent();

            function update() {
                var sliderBottom = $this.position().top + $this.outerHeight();
                var scrollPos = $(document).scrollTop() + 91;

                if (scrollPos > sliderBottom) return;

                scrollPos -= $('.headroom').outerHeight();

                var x = f(scrollPos, 0, 1, sliderBottom);

                var offset = x * ($this.outerHeight() - 46 ) / 4;

                var opacity = Math.max(1 - x, 0.6);
                var navOpacity = Math.min(Math.max(2 - Math.pow(2*x, 2), 0.1), 1);

                $this.find('.li-wrap').css({
                    top: offset,
                    opacity: opacity
                });

                $this.find('.flex-control-nav').css({
                    opacity: navOpacity
                });
            }

            function f(t, b, c, d) {
                return c * Math.sin(t/d * (Math.PI/2)) + b;
            }
        });
    };

    function mobileadjust() {
        windowWidth = $window.width();

        if( windowWidth < 680 ) {
            $('#slider .slides li').each(function(){
                var bgurl = $(this).css('background-image').match(/^url\(['"]?(.+)["']?\)$/)[1],
                    smallimg = $(this).data('smallimg');
                if ( !bgurl || typeof smallimg === 'undefined' || bgurl == smallimg ) return;
                $(this).css('background-image', 'url("' + smallimg + '")');
            });
        }

        if( windowWidth > 680 ) {
            $('#slider .slides li').each(function(){
                var bgurl = $(this).css('background-image').match(/^url\(['"]?(.+)["']?\)$/)[1],
                    bigimg = $(this).data('bigimg');
                if ( !bgurl || typeof bigimg === 'undefined' || bgurl == bigimg ) return;
                if ( !$(this).data('smallimg') ) $(this).data('smallimg', bgurl);
                $(this).css('background-image', 'url("' + bigimg + '")');
            });
        }

    }
})(jQuery);

function wpz_sliderTextAnimate(slider) {
    var $slides = slider.find('.slides > li');
    var $currentSlide = $slides.not('.clone').eq(slider.currentSlide);
    var $nextSlide = $slides.not('.clone').eq(slider.animatingTo);

    if (slider.vars.animation == 'swing' && typeof slider.direction !== 'undefined') {
        if (slider.count == slider.currentSlide + 1 && slider.direction == 'next') {
            $nextSlide = $nextSlide.add(slider.find('.clone:last'));
        } else if (slider.currentSlide == 0 && slider.direction == 'prev') {
            $nextSlide = $nextSlide.add(slider.find('.clone:first'));
        } else {
            slider.find('.clone h3').css({ 'margin-top': 0, 'opacity': 0 });
            slider.find('.clone .excerpt').css({ 'opacity': 0 });
        }
    }

    /* Text animation for slide that is dissapearing */
    $currentSlide.find('h3').stop().animate({'margin-top': 0, 'opacity': 0}, 800);
    $currentSlide.find('.excerpt').stop().animate({'opacity': 0}, 800);

    /* Text animation fro slide that is appearing */
    $nextSlide.find('h3').stop(true, true).css('opacity', 0).animate({'margin-top': '130px', 'opacity': 1}, 800);
    $nextSlide.find('.excerpt').stop(true, true).css('opacity', 0).animate({'opacity': 1}, 800);
}